==> mozilla-source-1.3.tar.bz2: mozilla/embedding/tests/mfcembed/Dialogs.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Chak Nanga <chak@netscape.com> 
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef _DIALOGS_H_
#define _DIALOGS_H_

#include "resource.h"

class CBrowserView;

class CFindDialog : public CFindReplaceDialog    
{
public:
    CFindDialog(CString& csSearchStr, PRBool bMatchCase,
                PRBool bMatchWholeWord, PRBool bWrapAround,
                PRBool bSearchBackwards, CBrowserView* pOwner);
    BOOL WrapAround();
    BOOL SearchBackwards();

private:
    CString m_csSearchStr;
    PRBool m_bMatchCase;
    PRBool m_bMatchWholeWord;
    PRBool m_bWrapAround;
    PRBool m_bSearchBackwards;
    CBrowserView* m_pOwner;

protected:
    virtual BOOL OnInitDialog();
    virtual void PostNcDestroy();
};

#endif //_DIALOG_H_

==> mozilla-source-1.7.tar.bz2: mozilla/embedding/tests/mfcembed/Dialogs.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Chak Nanga <chak@netscape.com> 
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef _DIALOGS_H_
#define _DIALOGS_H_

#include "resource.h"

class CBrowserView;

class CFindDialog : public CFindReplaceDialog    
{
public:
    CFindDialog(CString& csSearchStr, PRBool bMatchCase,
                PRBool bMatchWholeWord, PRBool bWrapAround,
                PRBool bSearchBackwards, CBrowserView* pOwner);
    BOOL WrapAround();
    BOOL SearchBackwards();

private:
    CString m_csSearchStr;
    PRBool m_bMatchCase;
    PRBool m_bMatchWholeWord;
    PRBool m_bWrapAround;
    PRBool m_bSearchBackwards;
    CBrowserView* m_pOwner;

protected:
    virtual BOOL OnInitDialog();
    virtual void PostNcDestroy();
};

/////////////////////////////////////////////////////////////////////////////
// CLinkPropertiesDlg dialog

class CLinkPropertiesDlg : public CDialog
{
public:
	CLinkPropertiesDlg(CWnd* pParent = NULL);

	enum { IDD = IDD_DIALOG_LINK_PROPERTIES };
	CString	m_LinkText;
	CString	m_LinkLocation;

protected:
	virtual void DoDataExchange(CDataExchange* pDX);
	virtual void OnOK();

	DECLARE_MESSAGE_MAP()
};

#endif //_DIALOG_H_
